package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.QyPerson;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 人员表Mapper接口
 * 
 * @author ruoyi
 * @date 2019-09-10
 */
public interface QyPersonMapper 
{
    /**
     * 查询人员表
     * 
     * @param id 人员表ID
     * @return 人员表
     */
    QyPerson selectQyPersonById(Long id);

    /**
     * 查询人员表列表
     * 
     * @param qyPerson 人员表
     * @return 人员表集合
     */
    List<QyPerson> selectQyPersonList(QyPerson qyPerson);

    /**
     * 新增人员表
     * 
     * @param qyPerson 人员表
     * @return 结果
     */
    int insertQyPerson(QyPerson qyPerson);

    /**
     * 修改人员表
     *
     * @param qyPerson 人员表
     * @return 结果
     */
    int updateQyPerson(QyPerson qyPerson);


    /**
     * 删除人员表
     * 
     * @param id 人员表ID
     * @return 结果
     */
    int deleteQyPersonById(Long id);

    /**
     * 批量删除人员表
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    int deleteQyPersonByIds(String[] ids);
    /**
     * 添加人员表
     *
     * @param
     * @return 结果
     */
    int SubmitCard(@Param("bsid") String bsid, @Param("renname") String renname,
                   @Param("rencardno") String rencardno, @Param("renphone") String renphone, @Param("renmoblie") String renmoblie,
                   @Param("renphoto") String renphoto, @Param("renqianming") String renqianming, @Param("paiphoto") String paiphoto,
                   @Param("addtime") Date addtime);


/**
 * 材料读取
 *
 * @param hyid 行业表ID
 * @return 结果
 */
List<Map> GetCailiao(@Param("hyid") String hyid);

/**
 * 存照片
 *
 * @param
 * @return 结果
 */
int updateCailiao(QyPerson qyPerson);

    /**
     * 根据bsid查询人员信息
     * @param
     * @return
     */
    List<QyPerson> selectQyPersonByBsid(String bsid);

    /**
     * 根据bsid查询人员信息
     * @param
     * @return
     */
    List<QyPerson> selectQyPersonByBsids(String bsid);
    /**
     * 修改人员表-委托人
     *
     * @param qyPerson 人员表
     * @return 结果
     */
    int updateWtr(QyPerson qyPerson);

}
